==> azureml_train_automl-1.0.18-py3-none-any.whl: azureml/train/automl/_vendor/automl/client/core/common/featurization/timeseries/missingdummies_transformer.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Add columns indicating corresponding numeric columns have NaN."""
import warnings
import pandas as pd
from sklearn.base import BaseEstimator, TransformerMixin

from automl.client.core.common.logging_utilities import function_debug_log_wrapped
from automl.client.core.common.featurization.logger import TransformerLogger

# Prevent warnings when using Jupyter
warnings.simplefilter("ignore")
pd.options.mode.chained_assignment = None


class MissingDummiesTransformer(BaseEstimator, TransformerMixin, TransformerLogger):
    """Add columns indicating corresponding numeric columns have NaN."""

    def __init__(self, numerical_columns, logger=None):
        """
        Construct for MissingDummiesTransformer.

        :param numerical_columns: The columns that will be marked.
        :type numerical_columns: list
        :return:
        """
        self._init_logger(logger)
        self.numerical_columns = numerical_columns

    def fit(self, x, y=None):
        """
        Fit function for MissingDummiesTransformer.

        :param x: Input data.
        :type x: TimeSeriesDataFrame
        :param y: Target values.
        :type y: numpy.ndarray
        :return: Class object itself.
        """
        return self

    @function_debug_log_wrapped
    def transform(self, x):
        """
        Transform function for MissingDummiesTransformer.

        :param x: Input data.
        :type x: TimeSeriesDataFrame
        :return: Result of MissingDummiesTransformer.
        """
        result = x.copy()
        for col in self.numerical_columns:
            is_null = result[col].isnull()
            result[col + '_WASNULL'] = is_null.apply(lambda x: int(x))
        return result

==> azureml_train_automl-1.0.23-py3-none-any.whl: azureml/train/automl/_vendor/automl/client/core/common/featurization/timeseries/missingdummies_transformer.py <==
# ---------------------------------------------------------
# Copyright (c) Microsoft Corporation. All rights reserved.
# ---------------------------------------------------------
"""Add columns indicating corresponding numeric columns have NaN."""
import warnings
import pandas as pd

from automl.client.core.common.logging_utilities import function_debug_log_wrapped
from automl.client.core.common.featurization.automltransformer import AutoMLTransformer

# Prevent warnings when using Jupyter
warnings.simplefilter("ignore")
pd.options.mode.chained_assignment = None


class MissingDummiesTransformer(AutoMLTransformer):
    """Add columns indicating corresponding numeric columns have NaN."""

    def __init__(self, numerical_columns, logger=None):
        """
        Construct for MissingDummiesTransformer.

        :param numerical_columns: The columns that will be marked.
        :type numerical_columns: list
        :return:
        """
        super().__init__()
        self._init_logger(logger)
        self.numerical_columns = numerical_columns

    def fit(self, x, y=None):
        """
        Fit function for MissingDummiesTransformer.

        :param x: Input data.
        :type x: TimeSeriesDataFrame
        :param y: Target values.
        :type y: numpy.ndarray
        :return: Class object itself.
        """
        return self

    @function_debug_log_wrapped
    def transform(self, x):
        """
        Transform function for MissingDummiesTransformer.

        :param x: Input data.
        :type x: TimeSeriesDataFrame
        :return: Result of MissingDummiesTransformer.
        """
        result = x.copy()
        for col in self.numerical_columns:
            is_null = result[col].isnull()
            result[col + '_WASNULL'] = is_null.apply(lambda x: int(x))
        return result
